MINOR: lua: use bitfield and macro in place of integer and enum

In the future, the lua execution must return scheduling informations.
We want more than one flag, so I convert an integer used with an
enum into an interer used as bitfield.
diff --git a/include/types/hlua.h b/include/types/hlua.h
index 2257d5c..5920e03 100644
--- a/include/types/hlua.h
+++ b/include/types/hlua.h
@@ -16,10 +16,7 @@
 
 struct session;
 
-enum hlua_state {
-	HLUA_STOP = 0,
-	HLUA_RUN,
-};
+#define HLUA_RUN       0x00000001
 
 enum hlua_exec {
 	HLUA_E_OK = 0,
@@ -37,7 +34,7 @@
 	int Mref; /* The reference of the memory context in coroutine case.
 	             -1 if the memory context is not used. */
 	int nargs; /* The number of arguments in the stack at the start of execution. */
-	enum hlua_state state; /* The current execution state. */
+	unsigned int flags; /* The current execution flags. */
 	struct task *task; /* The task associated with the lua stack execution.
 	                      We must wake this task to continue the task execution */
 	struct list com; /* The list head of the signals attached to this task. */